import 'dart:convert';

import 'package:http/http.dart' as http;

import 'package:pub_api_client/src/models/package_score_model.dart';
import 'package:pub_api_client/src/models/pub_package_model.dart';
import 'package:pub_api_client/src/models/search_results_model.dart';

const urlBase = 'https://pub.dartlang.org';
const searchUrl = '$urlBase/api/search';
const packageUrl = '$urlBase/api/packages';

String packageScoreUrl(String name) => '$urlBase/api/packages/$name/score';
String versionsUrl(String name) => 'https://pub.dev/packages/$name.json';

class PubClient {
  PubClient();
  Future<PubPackage> getPackage(String name) async {
    final response = await http.get('$packageUrl/$name');
    return PubPackage.fromJson(jsonDecode(response.body));
  }

  Future<PackageScore> getScore(String name) async {
    final response = await http.get(packageScoreUrl(name));
    return PackageScore.fromJson(jsonDecode(response.body));
  }

  Future<SearchResults> search(String query, {int page = 1}) async {
    final response = await http.get('$searchUrl?q=$query&page=$page');

    return SearchResults.fromJson(jsonDecode(response.body));
  }

  Future<List<String>> getVersions(String name) async {
    final response = await http.get(versionsUrl(name));
    final json = jsonDecode(response.body);
    final versions = <String>[];
    for (var version in json['versions']) {
      versions.add(version);
    }
    return versions;
  }
}
